@@ -31,46 +31,12 @@
 #include <glib/gprintf.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
-#include <glibtop/mountlist.h>
-#include <glibtop/fsusage.h>
 
 #include "baobab.h"
 #include "baobab-treeview.h"
 #include "baobab-utils.h"
 #include "callbacks.h"
 
-void
-baobab_get_filesystem (BaobabFS *fs)
-{
-	size_t i;
-	glibtop_mountlist mountlist;
-	glibtop_mountentry *mountentries;
-
-	memset (fs, 0, sizeof *fs);
-
-	mountentries = glibtop_get_mountlist (&mountlist, FALSE);
-
-	for (i = 0; i < mountlist.number; ++i) {
-		GFile *file;
-		glibtop_fsusage fsusage;
-
-		file = g_file_new_for_path (mountentries[i].mountdir);
-
-		if (!baobab_is_excluded_location (file)) {
-
-			glibtop_get_fsusage (&fsusage, mountentries[i].mountdir);
-
-			fs->total += fsusage.blocks * fsusage.block_size;
-			fs->avail += fsusage.bfree * fsusage.block_size;
-			fs->used += (fsusage.blocks - fsusage.bfree) * fsusage.block_size;
-		}
-
-		g_object_unref (file);
-	}
-
-	g_free (mountentries);
-}
-
 void
 filechooser_cb (GtkWidget *chooser,
                 gint response,
@@ -195,7 +161,7 @@ show_bars (GtkTreeModel *mdl,
  				    &readelements, -1);
                 
                 gtk_tree_model_get (mdl, iter, size_col, &size, -1);
-                sizecstr = g_format_size_for_display (size);
+                sizecstr = g_format_size (size);
 
  		if (readelements == -1) {
 			gtk_tree_store_set (GTK_TREE_STORE (mdl), iter,
@@ -220,7 +186,7 @@ show_bars (GtkTreeModel *mdl,
 		if (readelements != -1) {
 			gtk_tree_model_get (mdl, iter, size_col, &size,
 					    -1);
-			sizecstr = g_format_size_for_display (size);
+			sizecstr = g_format_size (size);
 
 			gtk_tree_store_set (GTK_TREE_STORE (mdl), iter,
 					    COL_H_PERC, 100.0,
@@ -353,10 +319,6 @@ void
 popupmenu_list (GtkTreePath *path, GdkEventButton *event, gboolean can_trash)
 {
 	GtkWidget *pmenu;
-	gchar *path_to_string;
-
-	/* path_to_string is freed in callback function */
-	path_to_string = gtk_tree_path_to_string (path);
 
 	pmenu = gtk_menu_new ();
 
@@ -380,54 +342,49 @@ popupmenu_list (GtkTreePath *path, GdkEventButton *event, gboolean can_trash)
 void
 open_file_with_application (GFile *file)
 {
-	GAppInfo *application;
-	gchar *primary;
 	GFileInfo *info;
-	gchar *uri_scheme;
-	const char *content;
-	gboolean local = FALSE;
 
 	info = g_file_query_info (file,
 				  G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
 				  G_FILE_QUERY_INFO_NONE,
 				  NULL,
 				  NULL);
-	if (!info) return;
-	
-	uri_scheme = g_file_get_uri_scheme (file);
-	if (g_ascii_strcasecmp(uri_scheme,"file") == 0)  local = TRUE;
-	
-	content = g_file_info_get_content_type (info);
-	application = g_app_info_get_default_for_type (content, TRUE);
+	if (info) {
+		GAppInfo *application;
+		const char *content;
 
-	if (!application) {
-			primary = g_strdup_printf (_("Could not open folder \"%s\""), 
-			                           g_file_get_basename (file));
-			message (primary, 
-			         _("There is no installed viewer capable "
-				   "of displaying the folder."),
-				 GTK_MESSAGE_ERROR,
-				 baobab.window);
-			g_free (primary);
+		content = g_file_info_get_content_type (info);
+		application = g_app_info_get_default_for_type (content, TRUE);
+
+		if (!application) {
+				gchar *primary;
+
+				primary = g_strdup_printf (_("Could not open folder \"%s\""), 
+					                   g_file_get_basename (file));
+				message (primary,
+					 _("There is no installed viewer capable "
+					   "of displaying the folder."),
+					 GTK_MESSAGE_ERROR,
+					 baobab.window);
+				g_free (primary);
+		}
+		else {
+			GList *uris = NULL;
+			gchar *uri;
+
+			uri = g_file_get_uri (file);
+			uris = g_list_append (uris, uri);
+			g_app_info_launch_uris (application, uris, NULL, NULL);
+
+			g_list_free (uris);
+			g_free (uri);
+		}
+
+		if (application)
+			g_object_unref (application);
+
+		g_object_unref (info);
 	}
-	else {
-		GList *uris = NULL;
-		gchar *uri;
-
-		uri = g_file_get_uri (file);
-		uris = g_list_append (uris, uri);
-		g_app_info_launch_uris (application, uris, NULL, NULL);
-
-		g_list_free (uris);
-		g_free (uri);
-	}
-
-	g_free (uri_scheme);
-
-	if (application)
-		g_object_unref (application);
-
-	g_object_unref (info);
 }
 
 gboolean
