@@ -874,13 +874,14 @@ finish_prepare_screenshot (char *initial_uri, GdkWindow *window, GdkRectangle *r
   GError *error = NULL;
   GdkRectangle rect;
   ScreenshotDialog *dialog;
+  gboolean include_mask = (!take_window_shot && !take_area_shot);
 
   /* always disable window border for full-desktop or selected-area screenshots */
   if (!take_window_shot)
-    screenshot = screenshot_get_pixbuf (window, rectangle, include_pointer, FALSE);
+    screenshot = screenshot_get_pixbuf (window, rectangle, include_pointer, FALSE, include_mask);
   else
     {
-      screenshot = screenshot_get_pixbuf (window, rectangle, include_pointer, include_border);
+      screenshot = screenshot_get_pixbuf (window, rectangle, include_pointer, include_border, include_mask);
 
       switch (border_effect[0])
         {
@@ -1002,10 +1003,7 @@ build_uri (AsyncExistenceJob *job)
   GDateTime *d;
 
   d = g_date_time_new_now_local ();
-  /* Translators: This is a strftime format string.
-		 * It is used to display the time in 24-hours format (eg, like
-		 * in France: 20:10). */
-  timestamp = g_date_time_format (d, _("%Y-%m-%d %H:%M:%S"));
+  timestamp = g_date_time_format (d, "%Y-%m-%d %H:%M:%S");
   g_date_time_unref (d);
 
   if (job->iteration == 0)
