@@ -427,14 +427,30 @@ create_select_window (void)
   return window;
 }
 
-gboolean
-screenshot_select_area (int *px,
-                        int *py,
-                        int *pwidth,
-                        int *pheight)
+typedef struct {
+  GdkRectangle rectangle;
+  SelectAreaCallback callback;
+} CallbackData;
+
+static gboolean
+emit_select_callback_in_idle (gpointer user_data)
+{
+  CallbackData *data = user_data;
+
+  data->callback (&data->rectangle);
+
+  g_slice_free (CallbackData, data);
+
+  return FALSE;
+}
+
+void
+screenshot_select_area_async (SelectAreaCallback callback)
 {
   GdkCursor               *cursor;
   select_area_filter_data  data;
+  GdkRectangle *rectangle;
+  CallbackData *cb_data;
 
   data.rect.x = 0;
   data.rect.y = 0;
@@ -443,6 +459,9 @@ screenshot_select_area (int *px,
   data.button_pressed = FALSE;
   data.window = create_select_window();
 
+  cb_data = g_slice_new0 (CallbackData);
+  cb_data->callback = callback;
+
   g_signal_connect (data.window, "key-press-event", G_CALLBACK (select_area_key_press), &data);
   g_signal_connect (data.window, "button-press-event", G_CALLBACK (select_area_button_press), &data);
   g_signal_connect (data.window, "button-release-event", G_CALLBACK (select_area_button_release), &data);
@@ -456,14 +475,14 @@ screenshot_select_area (int *px,
                         GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
     {
       gdk_cursor_unref (cursor);
-      return FALSE;
+      goto out;
     }
 
   if (gdk_keyboard_grab (gtk_widget_get_window (data.window), FALSE, GDK_CURRENT_TIME) != GDK_GRAB_SUCCESS)
     {
       gdk_pointer_ungrab (GDK_CURRENT_TIME);
       gdk_cursor_unref (cursor);
-      return FALSE;
+      goto out;
     }
 
   gtk_main ();
@@ -476,12 +495,14 @@ screenshot_select_area (int *px,
 
   gdk_flush ();
 
-  *px = data.rect.x;
-  *py = data.rect.y;
-  *pwidth  = data.rect.width;
-  *pheight = data.rect.height;
+ out:
+  cb_data->rectangle = data.rect;
 
-  return TRUE;
+  /* FIXME: we should actually be emitting the callback When
+   * the compositor has finished re-drawing, but there seems to be no easy
+   * way to know that.
+   */
+  g_timeout_add (200, emit_select_callback_in_idle, cb_data);
 }
 
 static Window
@@ -629,20 +650,13 @@ mask_monitors (GdkPixbuf *pixbuf, GdkWindow *root_window)
   cairo_region_destroy (invisible_region);
 }
 
-GdkPixbuf *
-screenshot_get_pixbuf (GdkWindow    *window,
-                       GdkRectangle *rectangle,
-                       gboolean      include_pointer,
-                       gboolean      include_border)
+static GdkWindow *
+screenshot_ensure_wm_window (GdkWindow *window)
 {
-  GdkWindow *root;
-  GdkPixbuf *screenshot;
-  gint x_real_orig, y_real_orig, x_orig, y_orig;
-  gint width, real_width, height, real_height;
+  GdkWindow *retval = window;
 
   /* If the screenshot should include the border, we look for the WM window. */
-
-  if (include_border)
+  if (window != gdk_get_default_root_window ())
     {
       Window xid, wm;
 
@@ -650,12 +664,23 @@ screenshot_get_pixbuf (GdkWindow    *window,
       wm = find_wm_window (xid);
 
       if (wm != None)
-        window = gdk_x11_window_foreign_new_for_display (gdk_window_get_display (window), wm);
+        retval = gdk_x11_window_foreign_new_for_display (gdk_window_get_display (window), wm);
 
       /* fallback to no border if we can't find the WM window. */
     }
 
-  root = gdk_get_default_root_window ();
+  return retval;
+}
+
+static void
+screenshot_get_window_rect_coords (GdkWindow *window,
+                                   gint *x_orig_out,
+                                   gint *y_orig_out,
+                                   gint *width_out,
+                                   gint *height_out)
+{
+  gint x_real_orig, y_real_orig, x_orig, y_orig;
+  gint width, real_width, height, real_height;
 
   real_width = gdk_window_get_width (window);
   real_height = gdk_window_get_height (window);
@@ -684,6 +709,49 @@ screenshot_get_pixbuf (GdkWindow    *window,
   if (y_orig + height > gdk_screen_height ())
     height = gdk_screen_height () - y_orig;
 
+  *x_orig_out = x_orig;
+  *y_orig_out = y_orig;
+  *width_out = width;
+  *height_out = height;
+}
+
+void
+screenshot_get_window_rect (GdkWindow *window,
+                            GdkRectangle *rect)
+{
+  GdkWindow *wm_window;
+
+  wm_window = screenshot_ensure_wm_window (window);
+  screenshot_get_window_rect_coords (wm_window,
+                                     &rect->x, &rect->y,
+                                     &rect->width, &rect->height);
+}
+
+GdkPixbuf *
+screenshot_get_pixbuf (GdkWindow    *window,
+                       GdkRectangle *rectangle,
+                       gboolean      include_pointer,
+                       gboolean      include_border,
+                       gboolean      include_mask)
+{
+  GdkWindow *root;
+  GdkPixbuf *screenshot;
+  gint x_real_orig, y_real_orig, x_orig, y_orig;
+  gint width, real_width, height, real_height;
+
+  if (include_border)
+    window = screenshot_ensure_wm_window (window);
+
+  root = gdk_get_default_root_window ();
+
+  gdk_window_get_origin (window, &x_real_orig, &y_real_orig);
+  real_width = gdk_window_get_width (window);
+  real_height = gdk_window_get_height (window);
+
+  screenshot_get_window_rect_coords (window, 
+                                     &x_orig, &y_orig,
+                                     &width, &height);
+
   if (rectangle)
     {
       x_orig = rectangle->x - x_orig;
@@ -696,7 +764,8 @@ screenshot_get_pixbuf (GdkWindow    *window,
                                            x_orig, y_orig,
                                            width, height);
 
-  mask_monitors (screenshot, root);
+  if (include_mask)
+    mask_monitors (screenshot, root);
 
 #ifdef HAVE_X11_EXTENSIONS_SHAPE_H
   if (include_border)
